# Modeling: Interfaces (Meta Model v3)
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/interfaces-modeling-v3#overview)
  * [Dataflow vs. Provider / Consumer](https://help.sap.com/docs/leanix/ea/interfaces-modeling-v3#dataflow-vs.-provider-/-consumer)
  * [Why is there only one provider application?](https://help.sap.com/docs/leanix/ea/interfaces-modeling-v3#why-is-there-only-one-provider-application?)
  * [How do I model interface technology?](https://help.sap.com/docs/leanix/ea/interfaces-modeling-v3#how-do-i-model-interface-technology?)
  * [Interface Attributes](https://help.sap.com/docs/leanix/ea/interfaces-modeling-v3#interface-attributes)


The Interface Fact Sheet addresses the Integration Architecture Management use case and can be used in combination with the Interface Circle Map and Data Flow Report.
**Note**
This page is a modeling guideline for Meta Model v3. For updated guidelines for Meta Model v4 see [Meta Model v4](https://help.sap.com/docs/leanix/ea/meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Get an overview of the SAP LeanIX meta model and its key concepts.").
